==> qtjambi-test-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiTest/QTest_QBenchmarkIterationController_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtTest/qbenchmark.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QTest_QBenchmarkIterationController(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QTest::QBenchmarkIterationController")
    QTest::QBenchmarkIterationController *_ptr = reinterpret_cast<QTest::QBenchmarkIterationController *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QBenchmarkIterationController()
void __qt_construct_QTest_QBenchmarkIterationController(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QBenchmarkIterationController()")
    Q_UNUSED(__java_arguments)
    QTest::QBenchmarkIterationController *__qt_this = new(__qtjambi_ptr) QTest::QBenchmarkIterationController();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QTest::QBenchmarkIterationController::QBenchmarkIterationController()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_test_QTest_00024QBenchmarkIterationController_initialize_1native__Lio_qt_test_QTest_00024QBenchmarkIterationController_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTest::QBenchmarkIterationController::QBenchmarkIterationController()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTest_QBenchmarkIterationController, sizeof(QTest::QBenchmarkIterationController), typeid(QTest::QBenchmarkIterationController), false, &deleter_QTest_QBenchmarkIterationController, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QBenchmarkIterationController(QTest::QBenchmarkIterationController)
void __qt_construct_QTest_QBenchmarkIterationController_cref_QTest_QBenchmarkIterationController(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QBenchmarkIterationController(QTest::QBenchmarkIterationController)")
    jobject other0 = __java_arguments[0].l;
    const QTest::QBenchmarkIterationController& __qt_other0 = qtjambi_cast<const QTest::QBenchmarkIterationController& >(__jni_env, other0);
    QTest::QBenchmarkIterationController *__qt_this = new(__qtjambi_ptr) QTest::QBenchmarkIterationController(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QTest::QBenchmarkIterationController::QBenchmarkIterationController(QTest::QBenchmarkIterationController)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_test_QTest_00024QBenchmarkIterationController_initialize_1native__Lio_qt_test_QTest_00024QBenchmarkIterationController_2Lio_qt_test_QTest_00024QBenchmarkIterationController_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTest::QBenchmarkIterationController::QBenchmarkIterationController(QTest::QBenchmarkIterationController)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTest_QBenchmarkIterationController_cref_QTest_QBenchmarkIterationController, sizeof(QTest::QBenchmarkIterationController), typeid(QTest::QBenchmarkIterationController), false, &deleter_QTest_QBenchmarkIterationController, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QBenchmarkIterationController(QTest::QBenchmarkIterationController::RunMode)
void __qt_construct_QTest_QBenchmarkIterationController_QTest_QBenchmarkIterationController_RunMode(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QBenchmarkIterationController(QTest::QBenchmarkIterationController::RunMode)")
    jobject runMode0 = __java_arguments[0].l;
    QTest::QBenchmarkIterationController::RunMode __qt_runMode0 = qtjambi_cast<QTest::QBenchmarkIterationController::RunMode>(__jni_env, runMode0);
    QTest::QBenchmarkIterationController *__qt_this = new(__qtjambi_ptr) QTest::QBenchmarkIterationController(QTest::QBenchmarkIterationController::RunMode(__qt_runMode0));
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QTest::QBenchmarkIterationController::QBenchmarkIterationController(QTest::QBenchmarkIterationController::RunMode)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_test_QTest_00024QBenchmarkIterationController_initialize_1native__Lio_qt_test_QTest_00024QBenchmarkIterationController_2Lio_qt_test_QTest_00024QBenchmarkIterationController_00024RunMode_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject runMode0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTest::QBenchmarkIterationController::QBenchmarkIterationController(QTest::QBenchmarkIterationController::RunMode)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = runMode0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTest_QBenchmarkIterationController_QTest_QBenchmarkIterationController_RunMode, sizeof(QTest::QBenchmarkIterationController), typeid(QTest::QBenchmarkIterationController), false, &deleter_QTest_QBenchmarkIterationController, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QTest::QBenchmarkIterationController
void __qt_destruct_QTest_QBenchmarkIterationController(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QTest::QBenchmarkIterationController")
    reinterpret_cast<QTest::QBenchmarkIterationController*>(ptr)->~QBenchmarkIterationController();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QTest::QBenchmarkIterationController::isDone()
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_test_QTest_00024QBenchmarkIterationController_isDone_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QTest::QBenchmarkIterationController *__qt_this = QtJambiAPI::objectFromNativeId<QTest::QBenchmarkIterationController>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTest::QBenchmarkIterationController::isDone()", __qt_this)
        __java_return_value = __qt_this->isDone();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTest::QBenchmarkIterationController::next()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_test_QTest_00024QBenchmarkIterationController_next_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QTest::QBenchmarkIterationController *__qt_this = QtJambiAPI::objectFromNativeId<QTest::QBenchmarkIterationController>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTest::QBenchmarkIterationController::next()", __qt_this)
        __qt_this->next();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_test_QTest_00024QBenchmarkIterationController_setI_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint i0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTest::QBenchmarkIterationController *__qt_this = QtJambiAPI::objectFromNativeId<QTest::QBenchmarkIterationController>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->i = static_cast<int>(i0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_test_QTest_00024QBenchmarkIterationController_i_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTest::QBenchmarkIterationController *__qt_this = QtJambiAPI::objectFromNativeId<QTest::QBenchmarkIterationController>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->i;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_test_QTest_00024QBenchmarkIterationController_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QTest::QBenchmarkIterationController *__qt_this = QtJambiAPI::objectFromNativeId<QTest::QBenchmarkIterationController>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QTest_QBenchmarkIterationController(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QTest::QBenchmarkIterationController>("QTest::QBenchmarkIterationController", "io/qt/test/QTest$QBenchmarkIterationController");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QTest_QBenchmarkIterationController, {
        ConstructorInfo(&__qt_construct_QTest_QBenchmarkIterationController, nullptr)
       ,ConstructorInfo(&__qt_construct_QTest_QBenchmarkIterationController_cref_QTest_QBenchmarkIterationController, "Lio/qt/test/QTest$QBenchmarkIterationController;")
       ,ConstructorInfo(&__qt_construct_QTest_QBenchmarkIterationController_QTest_QBenchmarkIterationController_RunMode, "Lio/qt/test/QTest$QBenchmarkIterationController$RunMode;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QTest_QBenchmarkIterationController);
    registerMetaType<QTest::QBenchmarkIterationController>("QTest::QBenchmarkIterationController");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QTest::QBenchmarkIterationController::RunMode>("QTest::QBenchmarkIterationController::RunMode", "io/qt/test/QTest$QBenchmarkIterationController$RunMode");
// END: enums and flags
}

==> qtjambi-test-debuginfo-linux-x64-6.7.0.jar: sources/QtJambiTest/QTest_QBenchmarkIterationController_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtTest/qbenchmark.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QTest_QBenchmarkIterationController(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QTest::QBenchmarkIterationController")
    QTest::QBenchmarkIterationController *_ptr = reinterpret_cast<QTest::QBenchmarkIterationController *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QBenchmarkIterationController()
void __qt_construct_QTest_QBenchmarkIterationController(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QBenchmarkIterationController()")
    Q_UNUSED(__java_arguments)
    QTest::QBenchmarkIterationController *__qt_this = new(__qtjambi_ptr) QTest::QBenchmarkIterationController();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QTest::QBenchmarkIterationController::QBenchmarkIterationController()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_test_QTest_00024QBenchmarkIterationController_initialize_1native__Lio_qt_test_QTest_00024QBenchmarkIterationController_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTest::QBenchmarkIterationController::QBenchmarkIterationController()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTest_QBenchmarkIterationController, sizeof(QTest::QBenchmarkIterationController), typeid(QTest::QBenchmarkIterationController), false, &deleter_QTest_QBenchmarkIterationController, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QBenchmarkIterationController(QTest::QBenchmarkIterationController)
void __qt_construct_QTest_QBenchmarkIterationController_cref_QTest_QBenchmarkIterationController(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QBenchmarkIterationController(QTest::QBenchmarkIterationController)")
    jobject other0 = __java_arguments[0].l;
    const QTest::QBenchmarkIterationController& __qt_other0 = qtjambi_cast<const QTest::QBenchmarkIterationController& >(__jni_env, other0);
    QTest::QBenchmarkIterationController *__qt_this = new(__qtjambi_ptr) QTest::QBenchmarkIterationController(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QTest::QBenchmarkIterationController::QBenchmarkIterationController(QTest::QBenchmarkIterationController)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_test_QTest_00024QBenchmarkIterationController_initialize_1native__Lio_qt_test_QTest_00024QBenchmarkIterationController_2Lio_qt_test_QTest_00024QBenchmarkIterationController_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTest::QBenchmarkIterationController::QBenchmarkIterationController(QTest::QBenchmarkIterationController)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTest_QBenchmarkIterationController_cref_QTest_QBenchmarkIterationController, sizeof(QTest::QBenchmarkIterationController), typeid(QTest::QBenchmarkIterationController), false, &deleter_QTest_QBenchmarkIterationController, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QBenchmarkIterationController(QTest::QBenchmarkIterationController::RunMode)
void __qt_construct_QTest_QBenchmarkIterationController_QTest_QBenchmarkIterationController_RunMode(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QBenchmarkIterationController(QTest::QBenchmarkIterationController::RunMode)")
    jobject runMode0 = __java_arguments[0].l;
    QTest::QBenchmarkIterationController::RunMode __qt_runMode0 = qtjambi_cast<QTest::QBenchmarkIterationController::RunMode>(__jni_env, runMode0);
    QTest::QBenchmarkIterationController *__qt_this = new(__qtjambi_ptr) QTest::QBenchmarkIterationController(QTest::QBenchmarkIterationController::RunMode(__qt_runMode0));
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QTest::QBenchmarkIterationController::QBenchmarkIterationController(QTest::QBenchmarkIterationController::RunMode)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_test_QTest_00024QBenchmarkIterationController_initialize_1native__Lio_qt_test_QTest_00024QBenchmarkIterationController_2Lio_qt_test_QTest_00024QBenchmarkIterationController_00024RunMode_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject runMode0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QTest::QBenchmarkIterationController::QBenchmarkIterationController(QTest::QBenchmarkIterationController::RunMode)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = runMode0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QTest_QBenchmarkIterationController_QTest_QBenchmarkIterationController_RunMode, sizeof(QTest::QBenchmarkIterationController), typeid(QTest::QBenchmarkIterationController), false, &deleter_QTest_QBenchmarkIterationController, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QTest::QBenchmarkIterationController
void __qt_destruct_QTest_QBenchmarkIterationController(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QTest::QBenchmarkIterationController")
    reinterpret_cast<QTest::QBenchmarkIterationController*>(ptr)->~QBenchmarkIterationController();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QTest::QBenchmarkIterationController::isDone()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_test_QTest_00024QBenchmarkIterationController_isDone_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QTest::QBenchmarkIterationController *__qt_this = QtJambiAPI::objectFromNativeId<QTest::QBenchmarkIterationController>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTest::QBenchmarkIterationController::isDone()const", __qt_this)
        __java_return_value = __qt_this->isDone();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QTest::QBenchmarkIterationController::next()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_test_QTest_00024QBenchmarkIterationController_next_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QTest::QBenchmarkIterationController *__qt_this = QtJambiAPI::objectFromNativeId<QTest::QBenchmarkIterationController>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QTest::QBenchmarkIterationController::next()", __qt_this)
        __qt_this->next();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_test_QTest_00024QBenchmarkIterationController_setI_1native_1int__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint i0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTest::QBenchmarkIterationController *__qt_this = QtJambiAPI::objectFromNativeId<QTest::QBenchmarkIterationController>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->i = static_cast<int>(i0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_test_QTest_00024QBenchmarkIterationController_i_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QTest::QBenchmarkIterationController *__qt_this = QtJambiAPI::objectFromNativeId<QTest::QBenchmarkIterationController>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        int  __qt_value = __qt_this->i;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_test_QTest_00024QBenchmarkIterationController_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QTest::QBenchmarkIterationController *__qt_this = QtJambiAPI::objectFromNativeId<QTest::QBenchmarkIterationController>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QTest_QBenchmarkIterationController(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QTest::QBenchmarkIterationController>("QTest::QBenchmarkIterationController", "io/qt/test/QTest$QBenchmarkIterationController");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QTest_QBenchmarkIterationController, {
        ConstructorInfo(&__qt_construct_QTest_QBenchmarkIterationController, nullptr)
       ,ConstructorInfo(&__qt_construct_QTest_QBenchmarkIterationController_cref_QTest_QBenchmarkIterationController, "Lio/qt/test/QTest$QBenchmarkIterationController;")
       ,ConstructorInfo(&__qt_construct_QTest_QBenchmarkIterationController_QTest_QBenchmarkIterationController_RunMode, "Lio/qt/test/QTest$QBenchmarkIterationController$RunMode;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QTest_QBenchmarkIterationController);
    registerMetaType<QTest::QBenchmarkIterationController>("QTest::QBenchmarkIterationController");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QTest::QBenchmarkIterationController::RunMode>("QTest::QBenchmarkIterationController::RunMode", "io/qt/test/QTest$QBenchmarkIterationController$RunMode");
// END: enums and flags
}
